NAME
chFormat_alSet.pl - converts an Alignment Set to NAACL or BLINKER format
SYNOPSIS
perl chFormat_alSet.pl [options] required_arguments
Required arguments:
--i_st, --i_sourceToTarget FILENAME Input source-to-target links file
--i_format BLINKER|GIZA|NAACL Input file(s) format (required if not NAACL)
--o_st, --o_sourceToTarget FILENAME Output source-to-target links file
--o_format BLINKER|GIZA|NAACL Output file(s) format (required if not NAACL)
Options:
--i_s, --i_source FILENAME Input source words file
--i_t, --i_target FILENAME Input target words file
--i_ts, --i_targetToSource FILENAME Input target-to-source links file
--o_s, --o_source FILENAME Output source words file
--o_t, --o_target FILENAME Output target words file
--o_ts, --o_targetToSource FILENAME Output target-to-source links file
--range BEGIN-END Input Alignment Set range
--alignMode as-is|null-align|no-null-align Alignment mode
--help|? Prints the help and exits
--man Prints the manual and exits
ARGUMENTS
- --i_st,--i_sourceToTarget FILENAME
-
Input source-to-target (i.e. links) file name (or directory, in case of BLINKER format)
- --i_format BLINKER|GIZA|NAACL
-
Input Alignment Set format (required if different from default, NAACL).
- --o_st,--o_sourceToTarget FILENAME
-
Output (new format) source-to-target (i.e. links) file name (or directory, in case of BLINKER format)
- --o_format BLINKER|GIZA|NAACL
-
Output (new) Alignment Set format (required if different from default, NAACL)
OPTIONS
- --i_s,--i_source FILENAME
-
Input source (words) file name. Not applicable in GIZA Format.
- --i_t,--i_target FILENAME
-
Input target (words) file name. Not applicable in GIZA Format.
- --i_ts,--i_targetToSource FILENAME
-
Input target-to-source (i.e. links) file name (or directory, in case of BLINKER format)
- --range BEGIN-END
-
Range of the input source-to-target file (BEGIN and END are the sentence pair numbers)
- --o_s,--o_source FILENAME
-
Output (new format) source (words) file name. Not applicable in GIZA Format.
- --o_t,--o_target FILENAME
-
Output (new format) target (words) file name. Not applicable in GIZA Format.
- --o_ts,--o_targetToSource FILENAME
-
Output (new format) target-to-source (i.e. links) file name (or directory, in case of BLINKER format)
- --alignMode as-is|null-align|no-null-align
-
Take alignment "as-is" or force NULL alignment or NO-NULL alignment (see AlignmentSet.pm documentation).
- --help, --?
-
Prints a help message and exits.
- --man
-
Prints a help message and exits.
DESCRIPTION
Converts an Alignment Set to the specified format. It creates, at the specified location, the new format file(s), but cannot delete the old format files. The command-line utility has been made for convenience. For full details, see the documentation of the Lingua::AlignmentSet.pm module.
EXAMPLES
Converting NAACL files to BLINKER format:
perl chFormat_alSet.pl --i_st test-giza.eng2spa.naacl --i_s test.eng.naacl --i_t test.spa.naacl --o_st test-giza.eng2spa.blinker --o_format BLINKER --o_s test.eng --o_t test.spa
Converting a GIZA file to NAACL format:
perl chFormat_alSet.pl --i_st test-giza.eng2spa.giza --i_format GIZA --o_st test-giza.eng2spa.naacl --o_s test.eng.naacl --o_t test.spa.naacl
AUTHOR
Patrik Lambert <lambert@talp.upc.es>
COPYRIGHT AND LICENSE
Copyright 2004 by Patrick Lambert
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License (version 2 or any later version).
3 POD Errors
The following errors were encountered while parsing the POD:
- Around line 135:
You forgot a '=back' before '=head1'
- Around line 137:
'=item' outside of any '=over'
- Around line 177:
You forgot a '=back' before '=head1'